Get and prepare basic soil hydraulic parameters from SSURGO via SDA
prepare_SSURGO_hydro_data(cokeys, max.depth)vector of component keys (cokey) in current SSURGO snapshot
target depth of aggregation, corrected later by real soil depth as reported by slab()
a list containing:
SPC: SoilProfileCollection
agg: aggregate representation of hydraulic parameters