A unique display of landform position probability.

vizGeomorphicComponent(
  x,
  s = NULL,
  annotations = TRUE,
  annotation.cex = 0.75,
  clust = TRUE,
  dend.size = 5,
  dend.type = c("rectangle", "triangle"),
  cols = c("#A8554E", "#DD9174", "#F6D4A9", "#DEE5D3", "#9FB9D9", "#5D74A5"),
  ...
)

Arguments

x

data.frame as created by soilDB::fetchOSD(..., extended = TRUE), see details

s

an optional soil series name, highlighted in the figure

annotations

logical, add number of record and normalized Shannon entropy values

annotation.cex

annotation label scaling factor

clust

logical, order rows using divisive hierarchical clustering and include dendrogram?

dend.size

numeric, space reserved for dendrogram when clust = TRUE: values between 3-10 are about right

dend.type

character, one of 'rectangle' or 'triangle', when clust = TRUE

cols

vector of colors

...

additional arguments to iterateHydOrder(): target = 0.9, maxIter = 20, j.amount = 0.001, verbose = FALSE

Value

A list with the following elements:

  • fig: lattice object (the figure)

  • order: 1D ordering from cluster::diana

  • clust: hclust object

  • match.rate: fraction of series matching target hydrologic ordering, after clustering + rotation

Details

See the Soil Series Query Functions tutorial for more information.

Note

Default colors are from PNWColors::pnw_palette('Shuksan2'). Previous colors: c("#D53E4F", "#FC8D59", "#FEE08B", "#E6F598", "#99D594", "#3288BD").

Author

D.E. Beaudette