A unique display of landform position probability.
vizGeomorphicComponent(x, s = NULL, annotations = TRUE, annotation.cex = 0.75)data.frame as created by soilDB::fetchOSD(..., extended=TRUE), see details
an optional soil series name, highlighted in the figure
logical, add number of record and normalized Shannon entropy values
annotation label scaling factor
a list with the following elements:
lattice object (the figure)
ordering of soil series
See the Soil Series Query Functions tutorial for more information.