A unique display of surface shape (typically curvature) probability, suitable for across-slope or down-slope shape. Use the title argument to make this clear.

vizSurfaceShape(
  x,
  title = "Surface Shape",
  s = NULL,
  annotations = TRUE,
  annotation.cex = 0.75,
  clust = TRUE,
  dend.size = 5,
  dend.type = c("rectangle", "triangle"),
  cols = c("#3D8399", "#E9D772", "#CF4F3F", "#808080", "#226222"),
  ...
)

Arguments

x

data.frame as created by soilDB::fetchOSD(..., extended = TRUE), see details

title

a reasonable title for the figure

s

an optional soil series name, highlighted in the figure

annotations

logical, add number of record and normalized Shannon entropy values

annotation.cex

annotation label scaling factor

clust

logical, order rows using divisive hierarchical clustering and include dendrogram?

dend.size

numeric, space reserved for dendrogram when clust = TRUE: values between 3-10 are about right

dend.type

character, one of 'rectangle' or 'triangle', when clust = TRUE

cols

vector of colors

...

additional arguments to iterateHydOrder(): target = 0.9, maxIter = 20, j.amount = 0.001, verbose = FALSE

Value

A list with the following elements:

  • fig: lattice object (the figure)

  • order: 1D ordering from cluster::diana

  • clust: hclust object

  • match.rate: fraction of series matching target hydrologic ordering, after clustering + rotation

Details

See the Soil Series Query Functions tutorial for more information.

Note

Default colors are from PNWColors::pnw_palette('Bay'). Original colors: c("#2B83BA", "#FFFFBF", "#D7191C", "#808080", "darkgreen").

Author

D.E. Beaudette