This function creates a graphical summary of geomorphic position proportions, as returned by soilDB::fetchOSD(..., extended = TRUE). Stacked barplots are arranged according to an expected hydrologic gradient from "higher" to "lower" relative positions in a theoretical landscape.

Example geomorphic position data:

seriesTreadRisernshannon_entropy
CAPSHAW0.9740.026390.172
GUTHRIE1.0000.000860.000
LEE1.0000.000420.000
LOBELVILLE1.0000.000260.000
TAFT1.0000.000900.000
TARKLIN0.6600.340530.924
TRACE1.0000.000120.000
vizTerracePosition(
  x,
  s = NULL,
  annotations = TRUE,
  annotation.cex = 0.75,
  clust = TRUE,
  dend.size = 5,
  dend.type = c("rectangle", "triangle"),
  cols = c("#5d74a5", "#fef7c7"),
  ...
)

Arguments

x

data.frame as created by soilDB::fetchOSD(..., extended = TRUE), see details

s

an optional soil series name, highlighted in the figure

annotations

logical, add number of record and normalized Shannon entropy values

annotation.cex

annotation label scaling factor

clust

logical, order rows using divisive hierarchical clustering and include dendrogram?

dend.size

numeric, space reserved for dendrogram when clust = TRUE: values between 3-10 are about right

dend.type

character, one of 'rectangle' or 'triangle', when clust = TRUE

cols

vector of colors

...

additional arguments to iterateHydOrder(): target = 0.9, maxIter = 20, j.amount = 0.001, verbose = FALSE

Value

A list with the following elements:

  • fig: lattice object (the figure)

  • order: 1D ordering from cluster::diana

  • clust: hclust object

  • match.rate: fraction of series matching target hydrologic ordering, after clustering + rotation

Details

See the Soil Series Query Functions tutorial for more information.

Note

Default colors are from PNWColors::pnw_palette('Shuksan2'). Original colors: c("#2B83BA", "#FDAE61")

Author

D.E. Beaudette